@@ -1,33 +1,34 @@
-# $Id: /local/CPAN/Mango/lib/Mango.pm 1203 2008-01-19T03:30:17.099341Z claco  $
+# $Id: /local/CPAN/Mango/lib/Mango.pm 1528 2008-04-14T01:08:40.114508Z claco  $
 package Mango;
 use strict;
 use warnings;
 
-our $VERSION = '0.01000_10';
+our $VERSION = '0.01000_11';
 
 BEGIN {
     use base qw/Class::Accessor::Grouped/;
     use File::ShareDir ();
     use Path::Class qw/dir/;
-};
+}
 
 sub share {
-    my ($self, $share) = @_;
+    my ( $self, $share ) = @_;
 
     if ($share) {
-        $self->set_inherited('share', $share);
-    };
+        $self->set_inherited( 'share', $share );
+    }
 
     return
-        $ENV{'MANGO_SHARE'} ||
-        $self->get_inherited('share') ||
+         $ENV{'MANGO_SHARE'}
+      || $self->get_inherited('share')
+      ||
 
-        ## use share, unless errors on local -I no share
-        eval{File::ShareDir::module_dir('Mango')} ||
+      ## use share, unless errors on local -I no share
+      eval { File::ShareDir::module_dir('Mango') } ||
 
-        ## try for -Ilib/Mango.pm../../share
-        dir($INC{'Mango.pm'})->parent->parent->subdir('share');
-};
+      ## try for -Ilib/Mango.pm../../share
+      dir( $INC{'Mango.pm'} )->parent->parent->subdir('share');
+}
 
 1;
 __END__
@@ -36,6 +37,11 @@ __END__
 
 Mango - An ecommerce solution using Catalyst, Handel and DBIx::Class
 
+=head1 SYNOPSIS
+
+    use Mango;
+    print Mango->share;
+
 =head1 DESCRIPTION
 
 This is a generic class containing the default configuration used by other
