@@ -1,3 +1,4 @@
+# $Id: /local/CPAN/Mango/lib/Mango/Catalyst/Controller/Logout.pm 1528 2008-04-14T01:08:40.114508Z claco  $
 package Mango::Catalyst::Controller::Logout;
 use strict;
 use warnings;
@@ -5,19 +6,19 @@ use warnings;
 BEGIN {
     use base qw/Mango::Catalyst::Controller/;
 
-    __PACKAGE__->config(
-        resource_name  => 'mango/logout'
-    );
-};
+    __PACKAGE__->config( resource_name => 'mango/logout' );
+}
 
 sub index : Template('logout/index') {
-    my ($self, $c) = @_;
+    my ( $self, $c ) = @_;
 
-    if ($c->user_exists) {
+    if ( $c->user_exists ) {
         $c->logout;
-        $c->stash->{'errors'} = [$c->localize('LOGOUT_SUCCEEDED')];
-    };
-};
+        $c->stash->{'errors'} = [ $c->localize('LOGOUT_SUCCEEDED') ];
+    }
+
+    return;
+}
 
 1;
 __END__
@@ -26,6 +27,11 @@ __END__
 
 Mango::Catalyst::Controller::Logout - Catalyst controller for logouts
 
+=head1 SYNOPSIS
+
+    package MyApp::Controller::Logout;
+    use base 'Mango::Catalyst::Controller::Logout';
+
 =head1 DESCRIPTION
 
 Mango::Catalyst::Controller::Logout provides the web interface for
