@@ -1,15 +1,13 @@
-# $Id: /local/CPAN/Mango/trunk/lib/Mango/Catalyst/Model/Orders.pm 1959 2007-08-10T05:27:29.884596Z claco  $
+# $Id: /local/CPAN/Mango/lib/Mango/Catalyst/Model/Orders.pm 1528 2008-04-14T01:08:40.114508Z claco  $
 package Mango::Catalyst::Model::Orders;
 use strict;
 use warnings;
 
 BEGIN {
     use base qw/Mango::Catalyst::Model::Provider/;
-};
+}
 
-__PACKAGE__->config(
-    provider_class => 'Mango::Provider::Orders'
-);
+__PACKAGE__->config( provider_class => 'Mango::Provider::Orders' );
 
 1;
 __END__
@@ -18,10 +16,15 @@ __END__
 
 Mango::Catalyst::Model::Orders - Catalyst model for order information
 
+=head1 SYNOPSIS
+
+    package MyApp::Model::Orders;
+    use base 'Mango::Catalyst::Model::Orders';
+
 =head1 DESCRIPTION
 
-Mango::Catalyst::Model::Orders provides glue between Mango::Provider::Orders and
-Catalyst models. If you would like to use a different provider, simply set
+Mango::Catalyst::Model::Orders provides glue between Mango::Provider::Orders
+and Catalyst models. If you would like to use a different provider, simply set
 C<provider_class>:
 
     __PACKAGE__->provider_class('OtherOrderProvider');
