@@ -1,15 +1,13 @@
-# $Id: /local/CPAN/Mango/trunk/lib/Mango/Catalyst/Model/Profiles.pm 1959 2007-08-10T05:27:29.884596Z claco  $
+# $Id: /local/CPAN/Mango/lib/Mango/Catalyst/Model/Profiles.pm 1528 2008-04-14T01:08:40.114508Z claco  $
 package Mango::Catalyst::Model::Profiles;
 use strict;
 use warnings;
 
 BEGIN {
     use base qw/Mango::Catalyst::Model::Provider/;
-};
+}
 
-__PACKAGE__->config(
-    provider_class => 'Mango::Provider::Profiles'
-);
+__PACKAGE__->config( provider_class => 'Mango::Provider::Profiles' );
 
 1;
 __END__
@@ -18,11 +16,16 @@ __END__
 
 Mango::Catalyst::Model::Profiles - Catalyst model for user profile information
 
+=head1 SYNOPSIS
+
+    package MyApp::Model::Profiles;
+    use base 'Mango::Catalyst::Model::Profiles';
+
 =head1 DESCRIPTION
 
-Mango::Catalyst::Model::Profiles provides glue between Mango::Provider::Profiles
-and Catalyst models. If you would like to use a different provider, simply set
-C<provider_class>:
+Mango::Catalyst::Model::Profiles provides glue between
+Mango::Provider::Profiles and Catalyst models. If you would like to use a
+different provider, simply set C<provider_class>:
 
     __PACKAGE__->provider_class('OtherProfilesProvider');
 
