@@ -1,15 +1,13 @@
-# $Id: /local/CPAN/Mango/trunk/lib/Mango/Catalyst/Model/Wishlists.pm 1959 2007-08-10T05:27:29.884596Z claco  $
+# $Id: /local/CPAN/Mango/lib/Mango/Catalyst/Model/Wishlists.pm 1528 2008-04-14T01:08:40.114508Z claco  $
 package Mango::Catalyst::Model::Wishlists;
 use strict;
 use warnings;
 
 BEGIN {
     use base qw/Mango::Catalyst::Model::Provider/;
-};
+}
 
-__PACKAGE__->config(
-    provider_class => 'Mango::Provider::Wishlists'
-);
+__PACKAGE__->config( provider_class => 'Mango::Provider::Wishlists' );
 
 1;
 __END__
@@ -18,6 +16,11 @@ __END__
 
 Mango::Catalyst::Model::Wishlists - Catalyst model for wishlist information
 
+=head1 SYNOPSIS
+
+    package MyApp::Model::Wishlists;
+    use base 'Mango::Catalyst::Model::Wishlists';
+
 =head1 DESCRIPTION
 
 Mango::Catalyst::Model::Wishlists provides glue between
