@@ -1,4 +1,4 @@
-# $Id: /local/CPAN/Mango/lib/Mango/Catalyst/Plugin/Authentication/Store.pm 1175 2008-01-12T05:03:21.523485Z claco  $
+# $Id: /local/CPAN/Mango/lib/Mango/Catalyst/Plugin/Authentication/Store.pm 1528 2008-04-14T01:08:40.114508Z claco  $
 package Mango::Catalyst::Plugin::Authentication::Store;
 use strict;
 use warnings;
@@ -7,106 +7,115 @@ our $VERSION = $Mango::VERSION;
 BEGIN {
     use base qw/Class::Accessor::Fast/;
 
-    use Clone ();
-    use Mango ();
-    use Mango::Catalyst::Plugin::Authentication::User ();
-    use Mango::Catalyst::Plugin::Authentication::CachedUser ();
+    use Clone                                                  ();
+    use Mango                                                  ();
+    use Mango::Catalyst::Plugin::Authentication::User          ();
+    use Mango::Catalyst::Plugin::Authentication::CachedUser    ();
     use Mango::Catalyst::Plugin::Authentication::AnonymousUser ();
-};
+}
 __PACKAGE__->mk_accessors(qw/config/);
 
 sub new {
-    my ($class, $config, $app) = @_;
+    my ( $class, $config, $app ) = @_;
 
-    $config->{'user_model'} ||= 'Users';
+    $config->{'user_model'}      ||= 'Users';
     $config->{'user_name_field'} ||= 'username';
-    $config->{'role_model'} ||= 'Roles';
+    $config->{'role_model'}      ||= 'Roles';
     $config->{'role_name_field'} ||= 'name';
-    $config->{'profile_model'} ||= 'Profiles';
-    $config->{'cart_model'} ||= 'Carts';
+    $config->{'profile_model'}   ||= 'Profiles';
+    $config->{'cart_model'}      ||= 'Carts';
 
-    return bless {config => $config}, $class;
-};
+    return bless { config => $config }, $class;
+}
 
 sub anonymous_user {
-    my ($self, $c) = (shift, shift);
+    my ( $self, $c ) = ( shift, shift );
 
-    return Mango::Catalyst::Plugin::Authentication::AnonymousUser->new(
-        $c, $self->config, @_
-    );
-};
+    return Mango::Catalyst::Plugin::Authentication::AnonymousUser->new( $c,
+        $self->config, @_ );
+}
 
 sub find_user {
-    my ($self, $authinfo, $c) = @_;
+    my ( $self, $authinfo, $c ) = @_;
     my $user_name_field = $self->config->{'user_name_field'};
-    my $name = $self->config->{'user_model'};
-    my $model = $c->model($name);
+    my $name            = $self->config->{'user_model'};
+    my $model           = $c->model($name);
 
-    Mango::Exception->throw('MODEL_NOT_FOUND', $name) unless $model;
+    if ( !$model ) {
+        Mango::Exception->throw( 'MODEL_NOT_FOUND', $name );
+    }
 
-    my $user = $model->search({
-        $user_name_field => $authinfo->{'username'}
-    })->first;
+    my $user =
+      $model->search( { $user_name_field => $authinfo->{'username'} } )
+      ->first;
 
     if ($user) {
-        my $user = Mango::Catalyst::Plugin::Authentication::User->new(
-            $c, $self->config, $user
-        );
+        my $user = Mango::Catalyst::Plugin::Authentication::User->new( $c,
+            $self->config, $user );
 
-        if ($authinfo->{'disable_sessions'}) {
+        if ( $authinfo->{'disable_sessions'} ) {
             $user->supports_sessions(undef);
-        };
+        }
         return $user;
     } else {
-        return undef;
-    };
-};
+        return;
+    }
+}
 
 sub user_supports {
     my $self = shift;
 
     return Mango::Catalyst::Plugin::Authentication::Store::User->supports(@_);
-};
+}
 
 sub for_session {
-    my ($self, $c, $user) = @_;
+    my ( $self, $c, $user ) = @_;
 
     ## don't store the password
     $user->password(undef);
 
     return {
-        user => {$user->get_columns},
-        profile => {$user->profile->get_columns},
-        roles => [$user->roles]
+        user    => { $user->get_columns },
+        profile => { $user->profile->get_columns },
+        roles   => [ $user->roles ]
     };
-};
+}
 
 sub from_session {
-    my ($self, $c, $data) = @_;
+    my ( $self, $c, $data ) = @_;
 
     ## restore user as user model result class
-    my $uname = $self->config->{'user_model'};
+    my $uname  = $self->config->{'user_model'};
     my $umodel = $c->model($uname);
-    Mango::Exception->throw('MODEL_NOT_FOUND', $uname) unless $umodel;
-    my $user = bless Clone::clone($data->{'user'}), $umodel->result_class;
+
+    if ( !$umodel ) {
+        Mango::Exception->throw( 'MODEL_NOT_FOUND', $uname );
+    }
+
+    my $user = bless Clone::clone( $data->{'user'} ), $umodel->result_class;
 
     ## restore profile as profile model result class
-    my $pname = $self->config->{'profile_model'};
+    my $pname  = $self->config->{'profile_model'};
     my $pmodel = $c->model($pname);
-    Mango::Exception->throw('MODEL_NOT_FOUND', $pname) unless $pmodel;
-    my $profile = bless Clone::clone($data->{'profile'}), $pmodel->result_class;
-    $profile->meta->provider($pmodel->provider);
 
-    my $restored = Mango::Catalyst::Plugin::Authentication::CachedUser->new(
-        $c, $self->config, $user
-    );
+    if ( !$pmodel ) {
+        Mango::Exception->throw( 'MODEL_NOT_FOUND', $pname );
+    }
+
+    my $profile = bless Clone::clone( $data->{'profile'} ),
+      $pmodel->result_class;
+    $profile->meta->provider( $pmodel->provider );
+
+    my $restored =
+      Mango::Catalyst::Plugin::Authentication::CachedUser->new( $c,
+        $self->config, $user );
     $restored->_profile($profile);
 
     ## restore role information
-    $restored->_roles($data->{'roles'});
+    $restored->_roles( $data->{'roles'} );
 
     return $restored;
-};
+}
 
 1;
 __END__
@@ -126,8 +135,8 @@ Mango::Catalyst::Plugin::Authentication::Store - Custom Catalyst Authentication
 
 =head1 DESCRIPTION
 
-Mango::Catalyst::Plugin::Authentication::Store is a custom authentication store
-that uses Mango Catalyst models to authenticate users.
+Mango::Catalyst::Plugin::Authentication::Store is a custom authentication
+store that uses Mango Catalyst models to authenticate users.
 
 To use this store, simply add it to the appropriate realm configuration:
 
