@@ -1,20 +1,26 @@
-# $Id: /local/CPAN/Mango/trunk/lib/Mango/Catalyst/View/XHTML.pm 1959 2007-08-10T05:27:29.884596Z claco  $
+# $Id: /local/CPAN/Mango/lib/Mango/Catalyst/View/XHTML.pm 1528 2008-04-14T01:08:40.114508Z claco  $
 package Mango::Catalyst::View::XHTML;
 use strict;
 use warnings;
 
 BEGIN {
     use base qw/Mango::Catalyst::View::Template/;
-    use Path::Class ()
-};
-__PACKAGE__->share_paths([
-    Path::Class::Dir->new(qw/templates %view html/),
-    Path::Class::Dir->new(qw/templates %view xhtml/)
-]);
-__PACKAGE__->root_paths([
-    Path::Class::Dir->new(qw/templates %view html/),
-    Path::Class::Dir->new(qw/templates %view xhtml/)
-]);
+    use Path::Class ();
+}
+__PACKAGE__->share_paths(
+    [
+        Path::Class::Dir->new(qw/templates %view html/),
+        Path::Class::Dir->new(qw/templates %view xhtml/)
+    ]
+);
+
+__PACKAGE__->root_paths(
+    [
+        Path::Class::Dir->new(qw/templates %view html/),
+        Path::Class::Dir->new(qw/templates %view xhtml/)
+    ]
+);
+
 __PACKAGE__->content_type('application/xhtml+xml; charset=utf-8');
 
 1;
@@ -64,8 +70,8 @@ Now, the template search path will be:
     /usr/local/share/Mango/templates/tt/xhtml
     /usr/local/share/Mango/templates/tt/html
 
-See L<Mango::Catalyst::View::Template|Mango::Catalyst::View::Template> for more
-information on changing the location of templates.
+See L<Mango::Catalyst::View::Template|Mango::Catalyst::View::Template> for
+more information on changing the location of templates.
 
 =head1 METHODS
 
