@@ -1,4 +1,4 @@
-# $Id: /local/CPAN/Mango/trunk/lib/Mango/Form/Results.pm 1959 2007-08-10T05:27:29.884596Z claco  $
+# $Id: /local/CPAN/Mango/lib/Mango/Form/Results.pm 1528 2008-04-14T01:08:40.114508Z claco  $
 package Mango::Form::Results;
 use strict;
 use warnings;
@@ -6,18 +6,20 @@ use warnings;
 BEGIN {
     use base qw/Class::Accessor::Grouped/;
 
-    __PACKAGE__->mk_group_accessors('simple', qw/_results errors/);
-};
+    __PACKAGE__->mk_group_accessors( 'simple', qw/_results errors/ );
+}
 
 sub new {
-    my ($class, $args) = @_;
+    my ( $class, $args ) = @_;
 
     return bless $args || {}, $class;
-};
+}
 
 sub success {
-    return shift->_results->success;
-};
+    my $self = shift;
+
+    return $self->_results->success;
+}
 
 1;
 __END__
