@@ -1,4 +1,4 @@
-# $Id: /local/CPAN/Mango/lib/Mango/Profile.pm 1199 2008-01-17T04:42:21.101109Z claco  $
+# $Id: /local/CPAN/Mango/lib/Mango/Profile.pm 1528 2008-04-14T01:08:40.114508Z claco  $
 package Mango::Profile;
 use strict;
 use warnings;
@@ -6,16 +6,17 @@ use warnings;
 BEGIN {
     use base qw/Mango::Object/;
 
-    __PACKAGE__->mk_group_accessors('column', qw/user_id first_name last_name/);
-};
+    __PACKAGE__->mk_group_accessors( 'column',
+        qw/user_id first_name last_name/ );
+}
 
 sub full_name {
     my $self = shift;
 
-    return $self->last_name ?
-        $self->first_name . ' ' . $self->last_name :
-        $self->first_name;
-};
+    return $self->last_name
+      ? $self->first_name . ' ' . $self->last_name
+      : $self->first_name;
+}
 
 1;
 __END__
@@ -60,6 +61,10 @@ Gets/sets the first name of the current profile.
 
     print $profile->first_name;
 
+=head2 full_name
+
+Returns the full name ("$firstname $lastname") for the current profile.
+
 =head2 id
 
 Returns the id of the current profile.
