@@ -1,4 +1,4 @@
-# $Id: /local/CPAN/Mango/trunk/lib/Mango/Provider/Carts.pm 1959 2007-08-10T05:27:29.884596Z claco  $
+# $Id: /local/CPAN/Mango/lib/Mango/Provider/Carts.pm 1528 2008-04-14T01:08:40.114508Z claco  $
 package Mango::Provider::Carts;
 use strict;
 use warnings;
@@ -6,95 +6,93 @@ use warnings;
 BEGIN {
     use base qw/Mango::Provider/;
 
-    __PACKAGE__->mk_group_accessors('simple', qw/storage/);
-};
+    __PACKAGE__->mk_group_accessors( 'simple', qw/storage/ );
+}
 __PACKAGE__->result_class('Mango::Cart');
 
 sub setup {
-    my ($self, $args) = @_;
+    my ( $self, $args ) = @_;
     my $storage = $self->result_class->storage->clone;
 
     $storage->setup($args);
 
-    $self->storage(
-        bless {storage => $storage}, $self->result_class
-    );
+    $self->storage( bless { storage => $storage }, $self->result_class );
 
     return;
-};
+}
 
 sub create {
     my $self = shift;
     my $data = shift || {};
 
-    if (my $user = delete $data->{'user'}) {
-        if (Scalar::Util::blessed($user)) {
-            if ($user->isa('Mango::User')) {
+    if ( my $user = delete $data->{'user'} ) {
+        if ( Scalar::Util::blessed($user) ) {
+            if ( $user->isa('Mango::User') ) {
                 $data->{'user_id'} = $user->id;
             } else {
                 Mango::Exception->throw('NOT_A_USER');
-            };
+            }
         } else {
             $data->{'user_id'} = $user;
-        };
-    };
+        }
+    }
 
-    return $self->storage->create($data, @_);
-};
+    return $self->storage->create( $data, @_ );
+}
 
 sub search {
     my $self = shift;
     my $filter = shift || {};
 
-    if (my $user = delete $filter->{'user'}) {
-        if (Scalar::Util::blessed $user) {
-            if ($user->isa('Mango::User')) {
+    if ( my $user = delete $filter->{'user'} ) {
+        if ( Scalar::Util::blessed $user) {
+            if ( $user->isa('Mango::User') ) {
                 $filter->{'user_id'} = $user->id;
             } else {
                 Mango::Exception->throw('NOT_A_USER');
-            };
+            }
         } else {
             $filter->{'user_id'} = $user;
-        };
-    };
+        }
+    }
 
-    return $self->storage->search($filter, @_);
-};
+    return $self->storage->search( $filter, @_ );
+}
 
 sub update {
-    my ($self, $object) = @_;
+    my ( $self, $object ) = @_;
 
     return $object->update;
-};
+}
 
 sub delete {
-    my $self = shift;
+    my $self   = shift;
     my $filter = shift;
 
-    if (Scalar::Util::blessed $filter) {
-        if ($filter->isa('Mango::Cart')) {
-            $filter = {id => $filter->id};
+    if ( Scalar::Util::blessed $filter) {
+        if ( $filter->isa('Mango::Cart') ) {
+            $filter = { id => $filter->id };
         } else {
             Mango::Exception->throw('NOT_A_CART');
-        };
-    } elsif (ref $filter eq 'HASH') {
-        if (my $user = delete $filter->{'user'}) {
-            if (Scalar::Util::blessed $user) {
-                if ($user->isa('Mango::User')) {
+        }
+    } elsif ( ref $filter eq 'HASH' ) {
+        if ( my $user = delete $filter->{'user'} ) {
+            if ( Scalar::Util::blessed $user) {
+                if ( $user->isa('Mango::User') ) {
                     $filter->{'user_id'} = $user->id;
                 } else {
                     Mango::Exception->throw('NOT_A_USER');
-                };
+                }
             } else {
                 $filter->{'user_id'} = $user;
-            };
-        };
+            }
+        }
     } else {
-        $filter = {id => $filter};
-    };
+        $filter = { id => $filter };
+    }
 
-    return $self->storage->destroy($filter, @_);
-};
+    return $self->storage->destroy( $filter, @_ );
+}
 
 1;
 __END__
@@ -148,7 +146,8 @@ Creates a new Mango::Cart object using the supplied data.
     
     print $cart->count;
 
-In addition to using the column names, the following special keys are available:
+In addition to using the column names, the following special keys are
+available:
 
 =over
 
@@ -179,7 +178,8 @@ Deletes carts from the provider matching the supplied filter.
         id => 23
     });
 
-In addition to using the column names, the following special keys are available:
+In addition to using the column names, the following special keys are
+available:
 
 =over
 
@@ -229,7 +229,8 @@ in scalar context matching the specified filter.
         name => 'A%'
     });
 
-In addition to using the column names, the following special keys are available:
+In addition to using the column names, the following special keys are
+available:
 
 =over
 
