@@ -1,4 +1,4 @@
-# $Id: /local/CPAN/Mango/lib/Mango/Schema/Cart/Item.pm 1117 2008-01-02T03:56:54.720997Z claco  $
+# $Id: /local/CPAN/Mango/lib/Mango/Schema/Cart/Item.pm 1528 2008-04-14T01:08:40.114508Z claco  $
 package Mango::Schema::Cart::Item;
 use strict;
 use warnings;
@@ -6,15 +6,17 @@ use warnings;
 BEGIN {
     use base qw/DBIx::Class/;
     use DateTime ();
-};
+}
 
-__PACKAGE__->load_components(qw/
-    +Handel::Components::DefaultValues
-    +Handel::Components::Constraints
-    +Handel::Components::Validation
-    InflateColumn::DateTime
-    Core
-/);
+__PACKAGE__->load_components(
+    qw/
+      +Handel::Components::DefaultValues
+      +Handel::Components::Constraints
+      +Handel::Components::Validation
+      InflateColumn::DateTime
+      Core
+      /
+);
 __PACKAGE__->table('cart_item');
 __PACKAGE__->source_name('CartItems');
 __PACKAGE__->add_columns(
@@ -22,31 +24,31 @@ __PACKAGE__->add_columns(
         data_type         => 'INT',
         is_auto_increment => 1,
         is_nullable       => 0,
-        extras            => {unsigned => 1}
+        extras            => { unsigned => 1 }
     },
     cart_id => {
-        data_type         => 'INT',
-        is_nullable       => 0,
-        is_foreign_key    => 1,
-        extras            => {unsigned => 1}
+        data_type      => 'INT',
+        is_nullable    => 0,
+        is_foreign_key => 1,
+        extras         => { unsigned => 1 }
     },
     sku => {
-        data_type      => 'VARCHAR',
-        size           => 25,
-        is_nullable    => 0,
+        data_type   => 'VARCHAR',
+        size        => 25,
+        is_nullable => 0,
     },
     quantity => {
-        data_type      => 'TINYINT',
-        size           => 3,
-        is_nullable    => 0,
-        default_value  => 1,
-        extras         => {unsigned => 1}
+        data_type     => 'TINYINT',
+        size          => 3,
+        is_nullable   => 0,
+        default_value => 1,
+        extras        => { unsigned => 1 }
     },
     price => {
-        data_type      => 'DECIMAL',
-        size           => [9,2],
-        is_nullable    => 0,
-        default_value  => '0.00'
+        data_type     => 'DECIMAL',
+        size          => [ 9, 2 ],
+        is_nullable   => 0,
+        default_value => '0.00'
     },
     description => {
         data_type     => 'VARCHAR',
@@ -55,28 +57,27 @@ __PACKAGE__->add_columns(
         default_value => undef
     },
     created => {
-        data_type     => 'DATETIME',
-        is_nullable   => 0,
-        extra         => {
-            timezone  => 'UTC'
-        }
+        data_type   => 'DATETIME',
+        is_nullable => 0,
+        extra       => { timezone => 'UTC' }
     },
     updated => {
-        data_type     => 'DATETIME',
-        is_nullable   => 0,
-        extra         => {
-            timezone  => 'UTC'
-        }
+        data_type   => 'DATETIME',
+        is_nullable => 0,
+        extra       => { timezone => 'UTC' }
     }
 );
 __PACKAGE__->set_primary_key('id');
-__PACKAGE__->belongs_to(cart => 'Mango::Schema::Cart',
-    {'foreign.id' => 'self.cart_id'}
+__PACKAGE__->belongs_to(
+    cart => 'Mango::Schema::Cart',
+    { 'foreign.id' => 'self.cart_id' }
+);
+__PACKAGE__->default_values(
+    {
+        created => sub { DateTime->now },
+        updated => sub { DateTime->now }
+    }
 );
-__PACKAGE__->default_values({
-    created => sub {DateTime->now},
-    updated => sub {DateTime->now}
-});
 
 1;
 __END__
@@ -93,7 +94,8 @@ Mango::Schema::Cart::Item - DBIC schema class for cart items
 
 =head1 DESCRIPTION
 
-Mango::Schema::Cart::Item is loaded by Mango::Schema to read/write cart item data.
+Mango::Schema::Cart::Item is loaded by Mango::Schema to read/write cart item
+data.
 
 =head1 COLUMNS
 
@@ -121,7 +123,8 @@ Contains the foreign key to the cart table.
 
 =head2 sku
 
-Contains the sku (Stock Keeping Unit), or part number for the current cart item.
+Contains the sku (Stock Keeping Unit), or part number for the current cart
+item.
 
     sku => {
         data_type      => 'VARCHAR',
@@ -186,4 +189,4 @@ When the cart item record was updated.
     Christopher H. Laco
     CPAN ID: CLACO
     claco@chrislaco.com
-    http://today.icantfocus.com/blog/
\ No newline at end of file
+    http://today.icantfocus.com/blog/
