@@ -1,4 +1,4 @@
-# $Id: /local/CPAN/Mango/lib/Mango/Schema/Order.pm 1117 2008-01-02T03:56:54.720997Z claco  $
+# $Id: /local/CPAN/Mango/lib/Mango/Schema/Order.pm 1528 2008-04-14T01:08:40.114508Z claco  $
 package Mango::Schema::Order;
 use strict;
 use warnings;
@@ -6,15 +6,17 @@ use warnings;
 BEGIN {
     use base qw/DBIx::Class/;
     use DateTime ();
-};
+}
 
-__PACKAGE__->load_components(qw/
-    +Handel::Components::DefaultValues
-    +Handel::Components::Constraints
-    +Handel::Components::Validation
-    InflateColumn::DateTime
-    Core
-/);
+__PACKAGE__->load_components(
+    qw/
+      +Handel::Components::DefaultValues
+      +Handel::Components::Constraints
+      +Handel::Components::Validation
+      InflateColumn::DateTime
+      Core
+      /
+);
 __PACKAGE__->table('orders');
 __PACKAGE__->source_name('Orders');
 __PACKAGE__->add_columns(
@@ -22,20 +24,20 @@ __PACKAGE__->add_columns(
         data_type         => 'INT',
         is_auto_increment => 1,
         is_nullable       => 0,
-        extras            => {unsigned => 1}
+        extras            => { unsigned => 1 }
     },
     user_id => {
         data_type      => 'INT',
         is_nullable    => 0,
         is_foreign_key => 1,
-        extras         => {unsigned => 1}
+        extras         => { unsigned => 1 }
     },
     type => {
         data_type     => 'TINYINT',
         size          => 3,
         is_nullable   => 0,
         default_value => 0,
-        extras        => {unsigned => 1}
+        extras        => { unsigned => 1 }
     },
     number => {
         data_type     => 'VARCHAR',
@@ -56,34 +58,34 @@ __PACKAGE__->add_columns(
         default_value => undef
     },
     shipping => {
-        data_type      => 'DECIMAL',
-        size           => [9,2],
-        is_nullable    => 0,
-        default_value  => '0.00'
+        data_type     => 'DECIMAL',
+        size          => [ 9, 2 ],
+        is_nullable   => 0,
+        default_value => '0.00'
     },
     handling => {
-        data_type      => 'DECIMAL',
-        size           => [9,2],
-        is_nullable    => 0,
-        default_value  => '0.00'
+        data_type     => 'DECIMAL',
+        size          => [ 9, 2 ],
+        is_nullable   => 0,
+        default_value => '0.00'
     },
     tax => {
-        data_type      => 'DECIMAL',
-        size           => [9,2],
-        is_nullable    => 0,
-        default_value  => '0.00'
+        data_type     => 'DECIMAL',
+        size          => [ 9, 2 ],
+        is_nullable   => 0,
+        default_value => '0.00'
     },
     subtotal => {
-        data_type      => 'DECIMAL',
-        size           => [9,2],
-        is_nullable    => 0,
-        default_value  => '0.00'
+        data_type     => 'DECIMAL',
+        size          => [ 9, 2 ],
+        is_nullable   => 0,
+        default_value => '0.00'
     },
     total => {
-        data_type      => 'DECIMAL',
-        size           => [9,2],
-        is_nullable    => 0,
-        default_value  => '0.00'
+        data_type     => 'DECIMAL',
+        size          => [ 9, 2 ],
+        is_nullable   => 0,
+        default_value => '0.00'
     },
     billtofirstname => {
         data_type     => 'VARCHAR',
@@ -251,25 +253,26 @@ __PACKAGE__->add_columns(
         data_type     => 'DATETIME',
         is_nullable   => 1,
         default_value => undef,
-        extra         => {
-            timezone  => 'UTC'
-        }
+        extra         => { timezone => 'UTC' }
     },
     updated => {
         data_type     => 'DATETIME',
         is_nullable   => 1,
         default_value => undef,
-        extra         => {
-            timezone  => 'UTC'
-        }
+        extra         => { timezone => 'UTC' }
     },
 );
 __PACKAGE__->set_primary_key('id');
-__PACKAGE__->has_many(items => 'Mango::Schema::Order::Item', {'foreign.order_id' => 'self.id'});
-__PACKAGE__->default_values({
-    created => sub {DateTime->now},
-    updated => sub {DateTime->now}
-});
+__PACKAGE__->has_many(
+    items => 'Mango::Schema::Order::Item',
+    { 'foreign.order_id' => 'self.id' }
+);
+__PACKAGE__->default_values(
+    {
+        created => sub { DateTime->now },
+        updated => sub { DateTime->now }
+    }
+);
 
 1;
 __END__
