@@ -1,4 +1,4 @@
-# $Id: /local/CPAN/Mango/trunk/lib/Mango/Schema/Order/Item.pm 1959 2007-08-10T05:27:29.884596Z claco  $
+# $Id: /local/CPAN/Mango/lib/Mango/Schema/Order/Item.pm 1528 2008-04-14T01:08:40.114508Z claco  $
 package Mango::Schema::Order::Item;
 use strict;
 use warnings;
@@ -6,15 +6,17 @@ use warnings;
 BEGIN {
     use base qw/DBIx::Class/;
     use DateTime ();
-};
+}
 
-__PACKAGE__->load_components(qw/
-    +Handel::Components::DefaultValues
-    +Handel::Components::Constraints
-    +Handel::Components::Validation
-    InflateColumn::DateTime
-    Core
-/);
+__PACKAGE__->load_components(
+    qw/
+      +Handel::Components::DefaultValues
+      +Handel::Components::Constraints
+      +Handel::Components::Validation
+      InflateColumn::DateTime
+      Core
+      /
+);
 __PACKAGE__->table('order_item');
 __PACKAGE__->source_name('OrderItems');
 __PACKAGE__->add_columns(
@@ -22,37 +24,37 @@ __PACKAGE__->add_columns(
         data_type         => 'INT',
         is_auto_increment => 1,
         is_nullable       => 0,
-        extras            => {unsigned => 1}
+        extras            => { unsigned => 1 }
     },
     order_id => {
         data_type      => 'INT',
         is_nullable    => 0,
         is_foreign_key => 1,
-        extras         => {unsigned => 1}
+        extras         => { unsigned => 1 }
     },
     sku => {
-        data_type      => 'VARCHAR',
-        size           => 25,
-        is_nullable    => 0,
+        data_type   => 'VARCHAR',
+        size        => 25,
+        is_nullable => 0,
     },
     quantity => {
-        data_type      => 'TINYINT',
-        size           => 3,
-        is_nullable    => 0,
-        default_value  => 1,
-        extras         => {unsigned => 1}
+        data_type     => 'TINYINT',
+        size          => 3,
+        is_nullable   => 0,
+        default_value => 1,
+        extras        => { unsigned => 1 }
     },
     price => {
-        data_type      => 'DECIMAL',
-        size           => [9,2],
-        is_nullable    => 0,
-        default_value  => '0.00'
+        data_type     => 'DECIMAL',
+        size          => [ 9, 2 ],
+        is_nullable   => 0,
+        default_value => '0.00'
     },
     total => {
-        data_type      => 'DECIMAL',
-        size           => [9,2],
-        is_nullable    => 0,
-        default_value  => '0.00'
+        data_type     => 'DECIMAL',
+        size          => [ 9, 2 ],
+        is_nullable   => 0,
+        default_value => '0.00'
     },
     description => {
         data_type     => 'VARCHAR',
@@ -61,22 +63,25 @@ __PACKAGE__->add_columns(
         default_value => undef
     },
     created => {
-        data_type     => 'DATETIME',
-        is_nullable   => 0
+        data_type   => 'DATETIME',
+        is_nullable => 0
     },
     updated => {
-        data_type     => 'DATETIME',
-        is_nullable   => 0
+        data_type   => 'DATETIME',
+        is_nullable => 0
     }
 );
 __PACKAGE__->set_primary_key('id');
-__PACKAGE__->belongs_to(order => 'Mango::Schema::Order',
-    {'foreign.id' => 'self.order_id'}
+__PACKAGE__->belongs_to(
+    order => 'Mango::Schema::Order',
+    { 'foreign.id' => 'self.order_id' }
+);
+__PACKAGE__->default_values(
+    {
+        created => sub { DateTime->now },
+        updated => sub { DateTime->now }
+    }
 );
-__PACKAGE__->default_values({
-    created => sub {DateTime->now},
-    updated => sub {DateTime->now}
-});
 
 1;
 __END__
@@ -93,7 +98,8 @@ Mango::Schema::Order::Item - DBIC schema class for order items
 
 =head1 DESCRIPTION
 
-Mango::Schema::Order::Item is loaded by Mango::Schema to read/write order item data.
+Mango::Schema::Order::Item is loaded by Mango::Schema to read/write order
+item data.
 
 =head1 COLUMNS
 
@@ -121,7 +127,8 @@ Contains the foreign key to the orders table.
 
 =head2 sku
 
-Contains the sku (Stock Keeping Unit), or part number for the current order item.
+Contains the sku (Stock Keeping Unit), or part number for the current order
+item.
 
     sku => {
         data_type      => 'VARCHAR',
