@@ -1,4 +1,4 @@
-# $Id: /local/CPAN/Mango/lib/Mango/Schema/Product.pm 1117 2008-01-02T03:56:54.720997Z claco  $
+# $Id: /local/CPAN/Mango/lib/Mango/Schema/Product.pm 1528 2008-04-14T01:08:40.114508Z claco  $
 package Mango::Schema::Product;
 use strict;
 use warnings;
@@ -6,16 +6,18 @@ use warnings;
 BEGIN {
     use base qw/DBIx::Class/;
     use Mango::Currency ();
-    use DateTime ();
-};
+    use DateTime        ();
+}
 
-__PACKAGE__->load_components(qw/
-    +Handel::Components::DefaultValues
-    +Handel::Components::Constraints
-    +Handel::Components::Validation
-    InflateColumn::DateTime
-    Core
-/);
+__PACKAGE__->load_components(
+    qw/
+      +Handel::Components::DefaultValues
+      +Handel::Components::Constraints
+      +Handel::Components::Validation
+      InflateColumn::DateTime
+      Core
+      /
+);
 __PACKAGE__->table('product');
 __PACKAGE__->source_name('Products');
 __PACKAGE__->add_columns(
@@ -23,12 +25,12 @@ __PACKAGE__->add_columns(
         data_type         => 'INT',
         is_auto_increment => 1,
         is_nullable       => 0,
-        extras            => {unsigned => 1}
+        extras            => { unsigned => 1 }
     },
     sku => {
-        data_type      => 'VARCHAR',
-        size           => 25,
-        is_nullable    => 0,
+        data_type   => 'VARCHAR',
+        size        => 25,
+        is_nullable => 0,
     },
     name => {
         data_type   => 'VARCHAR',
@@ -41,44 +43,46 @@ __PACKAGE__->add_columns(
         is_nullable => 1
     },
     price => {
-        data_type      => 'DECIMAL',
-        size           => [9,2],
-        is_nullable    => 0,
-        default_value  => '0.00'
+        data_type     => 'DECIMAL',
+        size          => [ 9, 2 ],
+        is_nullable   => 0,
+        default_value => '0.00'
     },
     created => {
-        data_type     => 'DATETIME',
-        is_nullable   => 0,
-        extra         => {
-            timezone  => 'UTC'
-        }
+        data_type   => 'DATETIME',
+        is_nullable => 0,
+        extra       => { timezone => 'UTC' }
     },
     updated => {
-        data_type     => 'DATETIME',
-        is_nullable   => 0,
-        extra         => {
-            timezone  => 'UTC'
-        }
+        data_type   => 'DATETIME',
+        is_nullable => 0,
+        extra       => { timezone => 'UTC' }
     }
 );
 __PACKAGE__->set_primary_key('id');
-__PACKAGE__->add_unique_constraint(
-    sku => [qw/sku/]
-);
+__PACKAGE__->add_unique_constraint( sku => [qw/sku/] );
 __PACKAGE__->has_many(
     map_product_tag => 'Mango::Schema::ProductTag',
-    {'foreign.product_id' => 'self.id'}
+    { 'foreign.product_id' => 'self.id' }
+);
+__PACKAGE__->many_to_many( tags => 'map_product_tag', 'product' );
+__PACKAGE__->has_many(
+    attributes => 'Mango::Schema::ProductAttribute',
+    { 'foreign.product_id' => 'self.id' }
+);
+__PACKAGE__->default_values(
+    {
+        created => sub { DateTime->now },
+        updated => sub { DateTime->now }
+    }
+);
+__PACKAGE__->inflate_column(
+    'price',
+    {
+        inflate => sub { Mango::Currency->new(shift); },
+        deflate => sub { shift->value; }
+    }
 );
-__PACKAGE__->many_to_many(tags => 'map_product_tag', 'product');
-__PACKAGE__->has_many(attributes => 'Mango::Schema::ProductAttribute', {'foreign.product_id' => 'self.id'});
-__PACKAGE__->default_values({
-    created => sub {DateTime->now},
-    updated => sub {DateTime->now}
-});
-__PACKAGE__->inflate_column('price', {
-    inflate => sub {Mango::Currency->new(shift);},
-    deflate => sub {shift->value;}
-});
 
 1;
 __END__
