@@ -1,4 +1,4 @@
-# $Id: /local/CPAN/Mango/lib/Mango/Schema/Profile.pm 1117 2008-01-02T03:56:54.720997Z claco  $
+# $Id: /local/CPAN/Mango/lib/Mango/Schema/Profile.pm 1528 2008-04-14T01:08:40.114508Z claco  $
 package Mango::Schema::Profile;
 use strict;
 use warnings;
@@ -6,15 +6,17 @@ use warnings;
 BEGIN {
     use base qw/DBIx::Class/;
     use DateTime ();
-};
+}
 
-__PACKAGE__->load_components(qw/
-    +Handel::Components::DefaultValues
-    +Handel::Components::Constraints
-    +Handel::Components::Validation
-    InflateColumn::DateTime
-    Core
-/);
+__PACKAGE__->load_components(
+    qw/
+      +Handel::Components::DefaultValues
+      +Handel::Components::Constraints
+      +Handel::Components::Validation
+      InflateColumn::DateTime
+      Core
+      /
+);
 __PACKAGE__->table('profile');
 __PACKAGE__->source_name('Profiles');
 __PACKAGE__->add_columns(
@@ -22,13 +24,13 @@ __PACKAGE__->add_columns(
         data_type         => 'INT',
         is_auto_increment => 1,
         is_nullable       => 0,
-        extras            => {unsigned => 1}
+        extras            => { unsigned => 1 }
     },
     user_id => {
         data_type      => 'INT',
         is_nullable    => 0,
         is_foreign_key => 1,
-        extras         => {unsigned => 1}
+        extras         => { unsigned => 1 }
     },
     first_name => {
         data_type   => 'VARCHAR',
@@ -41,31 +43,28 @@ __PACKAGE__->add_columns(
         is_nullable => 1
     },
     created => {
-        data_type     => 'DATETIME',
-        is_nullable   => 0,
-        extra         => {
-            timezone  => 'UTC'
-        }
+        data_type   => 'DATETIME',
+        is_nullable => 0,
+        extra       => { timezone => 'UTC' }
     },
     updated => {
-        data_type     => 'DATETIME',
-        is_nullable   => 0,
-        extra         => {
-            timezone  => 'UTC'
-        }
+        data_type   => 'DATETIME',
+        is_nullable => 0,
+        extra       => { timezone => 'UTC' }
     }
 );
 __PACKAGE__->set_primary_key('id');
-__PACKAGE__->add_unique_constraint(
-    user_id => [qw/user_id/]
+__PACKAGE__->add_unique_constraint( user_id => [qw/user_id/] );
+__PACKAGE__->belongs_to(
+    user => 'Mango::Schema::User',
+    { 'foreign.id' => 'self.user_id' }
 );
-__PACKAGE__->belongs_to(user => 'Mango::Schema::User',
-    {'foreign.id' => 'self.user_id'}
+__PACKAGE__->default_values(
+    {
+        created => sub { DateTime->now },
+        updated => sub { DateTime->now }
+    }
 );
-__PACKAGE__->default_values({
-    created => sub {DateTime->now},
-    updated => sub {DateTime->now}
-});
 
 1;
 __END__
@@ -82,7 +81,8 @@ Mango::Schema::Profile - DBIC schema class for Profiles
 
 =head1 DESCRIPTION
 
-Mango::Schema::Profile is loaded by Mango::Schema to read/write user profile data.
+Mango::Schema::Profile is loaded by Mango::Schema to read/write user profile
+data.
 
 =head1 COLUMNS
 
