@@ -1,4 +1,4 @@
-# $Id: /local/CPAN/Mango/lib/Mango/Schema/Wishlist/Item.pm 1169 2008-01-10T04:21:54.877465Z claco  $
+# $Id: /local/CPAN/Mango/lib/Mango/Schema/Wishlist/Item.pm 1528 2008-04-14T01:08:40.114508Z claco  $
 package Mango::Schema::Wishlist::Item;
 use strict;
 use warnings;
@@ -6,15 +6,17 @@ use warnings;
 BEGIN {
     use base qw/DBIx::Class/;
     use DateTime ();
-};
+}
 
-__PACKAGE__->load_components(qw/
-    +Handel::Components::DefaultValues
-    +Handel::Components::Constraints
-    +Handel::Components::Validation
-    InflateColumn::DateTime
-    Core
-/);
+__PACKAGE__->load_components(
+    qw/
+      +Handel::Components::DefaultValues
+      +Handel::Components::Constraints
+      +Handel::Components::Validation
+      InflateColumn::DateTime
+      Core
+      /
+);
 __PACKAGE__->table('wishlist_item');
 __PACKAGE__->source_name('WishlistItems');
 __PACKAGE__->add_columns(
@@ -22,26 +24,26 @@ __PACKAGE__->add_columns(
         data_type         => 'INT',
         is_auto_increment => 1,
         is_nullable       => 0,
-        extras            => {unsigned => 1}
+        extras            => { unsigned => 1 }
     },
     wishlist_id => {
         data_type         => 'INT',
         is_auto_increment => 1,
         is_nullable       => 0,
         is_foreign_key    => 1,
-        extras            => {unsigned => 1}
+        extras            => { unsigned => 1 }
     },
     sku => {
-        data_type      => 'VARCHAR',
-        size           => 25,
-        is_nullable    => 0,
+        data_type   => 'VARCHAR',
+        size        => 25,
+        is_nullable => 0,
     },
     quantity => {
-        data_type      => 'TINYINT',
-        size           => 3,
-        is_nullable    => 0,
-        default_value  => 1,
-        extras         => {unsigned => 1}
+        data_type     => 'TINYINT',
+        size          => 3,
+        is_nullable   => 0,
+        default_value => 1,
+        extras        => { unsigned => 1 }
     },
     description => {
         data_type     => 'VARCHAR',
@@ -50,32 +52,32 @@ __PACKAGE__->add_columns(
         default_value => undef
     },
     created => {
-        data_type     => 'DATETIME',
-        is_nullable   => 0,
-        extra         => {
-            timezone  => 'UTC'
-        }
+        data_type   => 'DATETIME',
+        is_nullable => 0,
+        extra       => { timezone => 'UTC' }
     },
     updated => {
-        data_type     => 'DATETIME',
-        is_nullable   => 0,
-        extra         => {
-            timezone  => 'UTC'
-        }
+        data_type   => 'DATETIME',
+        is_nullable => 0,
+        extra       => { timezone => 'UTC' }
     }
 );
 __PACKAGE__->set_primary_key('id');
-__PACKAGE__->belongs_to(wishlist => 'Mango::Schema::Wishlist',
-    {'foreign.id' => 'self.wishlist_id'}
+__PACKAGE__->belongs_to(
+    wishlist => 'Mango::Schema::Wishlist',
+    { 'foreign.id' => 'self.wishlist_id' }
 );
-__PACKAGE__->might_have(product => 'Mango::Schema::Product',
-    {'foreign.sku'    => 'self.sku'},
-    {'cascade_delete' => 0}
+__PACKAGE__->might_have(
+    product => 'Mango::Schema::Product',
+    { 'foreign.sku'    => 'self.sku' },
+    { 'cascade_delete' => 0 }
+);
+__PACKAGE__->default_values(
+    {
+        created => sub { DateTime->now },
+        updated => sub { DateTime->now }
+    }
 );
-__PACKAGE__->default_values({
-    created => sub {DateTime->now},
-    updated => sub {DateTime->now}
-});
 
 1;
 __END__
@@ -92,7 +94,8 @@ Mango::Schema::Wishlist::Item - DBIC schema class for wishlist items
 
 =head1 DESCRIPTION
 
-Mango::Schema::Wishlist::Item is loaded by Mango::Schema to read/write wishlist item data.
+Mango::Schema::Wishlist::Item is loaded by Mango::Schema to read/write
+wishlist item data.
 
 =head1 COLUMNS
 
@@ -120,7 +123,8 @@ Contains the foreign key to the wishlist table.
 
 =head2 sku
 
-Contains the sku (Stock Keeping Unit), or part number for the current wishlist item.
+Contains the sku (Stock Keeping Unit), or part number for the current
+wishlist item.
 
     sku => {
         data_type      => 'VARCHAR',
