@@ -1,4 +1,4 @@
-# $Id: /local/CPAN/Mango/lib/Mango/Tag.pm 1191 2008-01-14T03:37:39.681041Z claco  $
+# $Id: /local/CPAN/Mango/lib/Mango/Tag.pm 1528 2008-04-14T01:08:40.114508Z claco  $
 package Mango::Tag;
 use strict;
 use warnings;
@@ -7,16 +7,18 @@ BEGIN {
     use base qw/Mango::Object/;
     use Mango::Exception ();
 
-    __PACKAGE__->mk_group_accessors('column', qw/name/);
-};
+    __PACKAGE__->mk_group_accessors( 'column', qw/name/ );
+}
 
 sub count {
     return shift->{'count'} || 0;
-};
+}
 
 sub destroy {
     Mango::Exception->throw('METHOD_NOT_IMPLEMENTED');
-};
+
+    return;
+}
 
 1;
 __END__
